defmodule Backend.MixProject do
  use Mix.Project

  def project do
    [
      app: :backend,
      version: "2.8.2",
      elixir: "~> 1.5",
      elixirc_paths: elixirc_paths(Mix.env()),
      compilers: [:phoenix, :gettext] ++ Mix.compilers(),
      start_permanent: Mix.env() == :prod,
      aliases: aliases(),
      deps: deps()
    ]
  end

  # Configuration for the OTP application.
  #
  # Type `mix help compile.app` for more information.
  def application do
    [
      mod: {Backend.Application, []},
      extra_applications: [
        :logger,
        :runtime_tools,
        :mnesia,
        :gollum,
        :ex_twilio,
        :elasticsearch,
        :appsignal
      ]
    ]
  end

  # Specifies which paths to compile per environment.
  defp elixirc_paths(:test), do: ["lib", "test/support"]
  defp elixirc_paths(_), do: ["lib"]

  # Specifies your project dependencies.
  #
  # Type `mix help deps` for examples and options.
  defp deps do
    [
      {:phoenix, "~> 1.4.3"},
      {:phoenix_pubsub, "~> 1.1"},
      {:phoenix_ecto, "~> 4.0"},
      {:ecto_sql, "~> 3.0"},
      {:postgrex, ">= 0.0.0"},
      {:gettext, "~> 0.11"},
      {:jason, "~> 1.0"},
      {:plug_cowboy, "~> 2.0"},
      {:httpoison, "~> 1.5"},
      {:timex, "~> 3.5"},
      {:honeydew, "~> 1.4.3"},
      {:quantum, "~> 2.3"},
      {:corsica, "~> 1.1.2"},
      {:sobelow, "~> 0.8", only: [:dev, :test]},
      {:gollum, "~> 0.3.2"},
      {:public_suffix, "~> 0.6.0"},
      {:idna, "~> 5.1.2", override: true},
      {:swoosh, "~> 0.23.3"},
      {:ex_twilio, "~> 0.7.0"},
      {:elasticsearch, "~> 1.0"},
      {:appsignal, "~> 1.10.1"},
      {:credo, "~> 1.1", only: [:dev, :test], runtime: false},
      {:nebulex, "~> 1.1"},
      {:hunter, "~> 0.5.1"},
      {:poison, "~> 4.0", override: true},
      {:scrivener_ecto, "~> 2.2"},
      {:recase, "~> 0.6.0"},
      {:ex_rated, "~> 1.3"},
      {:html_sanitize_ex, "~> 1.4"}
    ]
  end

  # Aliases are shortcuts or tasks specific to the current project.
  # For example, to create, migrate and run the seeds file at once:
  #
  #     $ mix ecto.setup
  #
  # See the documentation for `Mix` for more info on aliases.
  defp aliases do
    [
      "ecto.setup": ["ecto.create", "ecto.migrate", "run priv/repo/seeds.exs"],
      "ecto.reset": ["ecto.drop", "ecto.setup"],
      test: ["ecto.create --quiet", "ecto.migrate", "test"]
    ]
  end
end
